Crystal Palace 0 - 0 Manchester United (March 03 2021) | EPL | 2020/2021 | xG | Understat.com
Description: Crystal Palace 0 - 0 Manchester United. Check out detailed player statistic, goals, assists, key passes, xG, shot map, xGplot.
Keywords: Crystal Palace, Manchester United, EPL, 2020/2021, (March 03 2021), xG, expected goals, shot map

Field Timing chart Stats
TEAMS
Crystal Palace
Manchester United
CHANCES
38%
38%
24%
GOALS
0
0
xG
0.74
0.58
SHOTS
8
11
SHOTS ON TARGET
2
1
DEEP
3
8
PPDA
16.47
10.74
xPTS
1.51
1.11

### Crystal Palace

GK
Vicente Guaita
90' DR
Joel Ward
90' DC
Cheikhou Kouyaté
90' DC
Gary Cahill
90' DL
Patrick van Aanholt
90' MR
Andros Townsend
90' MC
Luka Milivojevic
90' MC
James McCarthy
62' Sub
Jairo Riedewald
28' ML
Eberechi Eze
84' Sub
Jeffrey Schlupp
6' FW
Jordan Ayew
90' FW
Christian Benteke
90'

### Manchester United

GK
Dean Henderson
90' DR
Aaron Wan-Bissaka
90' DC
Eric Bailly
90' DC
Harry Maguire
90' DL
Luke Shaw
90' DMC
Nemanja Matic
90' DMC
Fred
74' Sub
Scott McTominay
16' AMR
Mason Greenwood
90' AMC
Bruno Fernandes
90' AML
Marcus Rashford
90' FW
Edinson Cavani
76' Sub
Daniel James
14'
James McCarthy Jairo Riedewald
62'
74'
Fred Scott McTominay
76'
Edinson Cavani Daniel James
Eberechi Eze Jeffrey Schlupp
84'
Jairo Riedewald
92'
Crystal Palace Manchester United